@@ -861,7 +861,8 @@ class CloudVerification:
         Returns
         -------
         Response
-            S3 response - can be handled as a json object
+            S3 response if successfull - can be handled as a json object
+            None if excepted
         """
         upload_fail_msg = f"couldn't upload file - {file_to_upload}"
         try:
@@ -869,13 +870,16 @@ class CloudVerification:
                 http_response = requests.put(presigned_url, data=my_file, headers={"content-type": "application/zip"})
         except ConnectionError as e:
             cloud_logger.error(f"{CONNECTION_ERR_PREFIX} {upload_fail_msg}", exc_info=e)
+            return None
         except requests.exceptions.Timeout as e:
             cloud_logger.error(f"{TIMEOUT_MSG_PREFIX} {upload_fail_msg}", exc_info=e)
+            return None
         except requests.exceptions.RequestException as e:
             cloud_logger.error(f"{GENERAL_ERR_PREFIX} {upload_fail_msg}", exc_info=e)
             return None
         except OSError as e:
             cloud_logger.error(f"OSError: {upload_fail_msg}", exc_info=e)
+            return None
 
         return http_response
 
